import { Part } from 'vscode/vscode/vs/workbench/browser/part';
import { IWorkbenchLayoutService, Parts } from 'vscode/vscode/vs/workbench/services/layout/browser/layoutService';
import { IInstantiationService } from 'vscode/vscode/vs/platform/instantiation/common/instantiation';
import { IThemeService } from 'vscode/vscode/vs/platform/theme/common/themeService';
import { IConfigurationService } from 'vscode/vscode/vs/platform/configuration/common/configuration';
import { IAction } from 'vscode/vscode/vs/base/common/actions';
import { IPaneCompositePart } from '../paneCompositePart.js';
import { PaneCompositeBar, IPaneCompositeBarOptions } from '../paneCompositeBar.js';
import { IStorageService } from 'vscode/vscode/vs/platform/storage/common/storage';
import { IMenuService } from 'vscode/vscode/vs/platform/actions/common/actions';
import { IContextKeyService } from 'vscode/vscode/vs/platform/contextkey/common/contextkey';
import { IViewDescriptorService } from 'vscode/vscode/vs/workbench/common/views';
import { IExtensionService } from 'vscode/vscode/vs/workbench/services/extensions/common/extensions';
import { IWorkbenchEnvironmentService } from 'vscode/vscode/vs/workbench/services/environment/common/environmentService';

declare class ActivitybarPart extends Part {
    private readonly paneCompositePart;
    private readonly instantiationService;
    static readonly ACTION_HEIGHT = 48;
    static readonly pinnedViewContainersKey = "workbench.activity.pinnedViewlets2";
    static readonly placeholderViewContainersKey = "workbench.activity.placeholderViewlets";
    static readonly viewContainersWorkspaceStateKey = "workbench.activity.viewletsWorkspaceState";
    readonly minimumWidth: number;
    readonly maximumWidth: number;
    readonly minimumHeight: number;
    readonly maximumHeight: number;
    private readonly compositeBar;
    private content;
    constructor(paneCompositePart: IPaneCompositePart, instantiationService: IInstantiationService, layoutService: IWorkbenchLayoutService, themeService: IThemeService, storageService: IStorageService);
    private createCompositeBar;
    protected createContentArea(parent: HTMLElement): HTMLElement;
    getPinnedPaneCompositeIds(): string[];
    getVisiblePaneCompositeIds(): string[];
    focus(): void;
    updateStyles(): void;
    show(focus?: boolean): void;
    hide(): void;
    layout(width: number, height: number): void;
    toJSON(): object;
}
declare class ActivityBarCompositeBar extends PaneCompositeBar {
    private readonly configurationService;
    private readonly menuService;
    private element;
    private menuBar;
    private menuBarContainer;
    private compositeBarContainer;
    private readonly globalCompositeBar;
    private readonly keyboardNavigationDisposables;
    constructor(options: IPaneCompositeBarOptions, part: Parts, paneCompositePart: IPaneCompositePart, showGlobalActivities: boolean, instantiationService: IInstantiationService, storageService: IStorageService, extensionService: IExtensionService, viewDescriptorService: IViewDescriptorService, contextKeyService: IContextKeyService, environmentService: IWorkbenchEnvironmentService, configurationService: IConfigurationService, menuService: IMenuService, layoutService: IWorkbenchLayoutService);
    private fillContextMenuActions;
    private uninstallMenubar;
    private installMenubar;
    private registerKeyboardNavigationListeners;
    create(parent: HTMLElement): HTMLElement;
    layout(width: number, height: number): void;
    getActivityBarContextMenuActions(): IAction[];
}

export { ActivityBarCompositeBar, ActivitybarPart };
